@@ -1,18 +1,7 @@
 /*
- *   Copyright (C) 2003 Waldo Bastian <bastian@kde.org>
+ *   SPDX-FileCopyrightText: 2003 Waldo Bastian <bastian@kde.org>
  *
- *   This program is free software; you can redistribute it and/or modify
- *   it under the terms of the GNU General Public License version 2 as
- *   published by the Free Software Foundation.
- *
- *   This program is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU General Public License for more details.
- *
- *   You should have received a copy of the GNU General Public License
- *   along with this program; if not, write to the Free Software
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+ *   SPDX-License-Identifier: GPL-2.0-only
  *
  */
 
@@ -27,8 +16,8 @@
 class MenuFile
 {
 public:
-    static const QString MF_MENU, MF_PUBLIC_ID, MF_SYSTEM_ID, MF_NAME, MF_INCLUDE, MF_EXCLUDE, MF_FILENAME, MF_DELETED, MF_NOTDELETED,
-                         MF_MOVE, MF_OLD, MF_NEW, MF_DIRECTORY, MF_LAYOUT, MF_MENUNAME, MF_SEPARATOR, MF_MERGE;
+    static const QString MF_MENU, MF_PUBLIC_ID, MF_SYSTEM_ID, MF_NAME, MF_INCLUDE, MF_EXCLUDE, MF_FILENAME, MF_DELETED, MF_NOTDELETED, MF_MOVE, MF_OLD, MF_NEW,
+        MF_DIRECTORY, MF_LAYOUT, MF_MENUNAME, MF_SEPARATOR, MF_MERGE;
 
     explicit MenuFile(const QString &file);
     ~MenuFile();
@@ -39,7 +28,7 @@ public:
     QString error() const
     {
         return m_error;
-    }                                        // Returns the last error message
+    } // Returns the last error message
 
     void restoreMenuSystem(const QString &);
 
@@ -48,11 +37,10 @@ public:
         REMOVE_ENTRY,
         ADD_MENU,
         REMOVE_MENU,
-        MOVE_MENU
+        MOVE_MENU,
     };
 
-    struct ActionAtom
-    {
+    struct ActionAtom {
         ActionType action;
         QString arg1;
         QString arg2;
